@@ -107,3 +107,38 @@ class ctpysql:
 
         except Error as e:
             return e
+
+    def drop(self, case, name):
+        # case: can define what we want to drop, like: 'table' or 'veiw'
+        # name: name of our case
+        sql = "DROP {0} {1}".format(case, name)
+        try:
+            cursor = self.conn.cursor()
+            cursor.execute(sql)
+            self.conn.commit()
+            cursor.close()
+            return "Success"
+
+        except Error as e:
+            return e
+
+    def order(self, table, **data):
+        # table: table name
+        # **data: kwargs data like: name="ASC", id="DESC"
+        sql = "SELECT * FROM {0} ORDER BY ".format(table)
+        i = 0
+        for key, value in data.items():
+            sql += "{0} {1}".format(key, value)
+
+            if i < len(data.items())-1:
+                sql += ", "
+            i += 1
+
+        try:
+            cursor = self.conn.cursor()
+            cursor.execute(sql)
+            return cursor.fetchall()
+            cursor.close()
+
+        except Error as e:
+            return e
